Learn R Programming

rofanova (version 1.0.1)

rofanova-package: Robust Functional Analysis of Variance

Description

Implements the robust functional analysis of variance (RoFANOVA), described in Centofanti et al. (2023) tools:::Rd_expr_doi("10.1093/jrsssc/qlad074"). It allows testing mean differences among groups of functional data by being robust against the presence of outliers.

Arguments

Author

Fabio Centofanti

Details

Package:rofanova
Type:Package
Version:1.0.1
Date:2025-12-27
License:GPL-3

References

Centofanti, F., Colosimo, B. M., Grasso, M. L., Menafoglio, A., Palumbo, B., & Vantini, S. (2023). Robust functional ANOVA with application to additive manufacturing. Journal of the Royal Statistical Society Series C: Applied Statistics, 72(5), 1210-1234.

See Also

rofanova fusem funmad

Examples

Run this code
library(rofanova)
data_out<-simulate_data(scenario="one-way")
label_1=data_out$label_1
X_fdata<-data_out$X_fdata
B=10
cores=1
per_list_median<-rofanova(X_fdata,label_1,B = B,family="median",cores=cores)
pvalue_median_vec<-per_list_median$pval_vec
per_list_huber<-rofanova(X_fdata,label_1,B = B,family="huber",cores=cores)
pvalue_huber_vec<-per_list_huber$pval_vec
per_list_bisquare<-rofanova(X_fdata,label_1,B = B,family="bisquare",cores=cores)
pvalue_bisquare_vec<-per_list_bisquare$pval_vec
per_list_hampel<-rofanova(X_fdata,label_1,B = B,family="hampel",cores=cores)
pvalue_hampel_vec<-per_list_hampel$pval_vec
per_list_optimal<-rofanova(X_fdata,label_1,B = B,family="optimal",cores=cores)
pvalue_optimal<-per_list_optimal$pval

Run the code above in your browser using DataLab