Compute the scale equivariant functional M-estimator as described in Centofanti et al. (2023).
fusem(
X,
family = "bisquare",
eff = 0.95,
maxit = 50,
tol = 1e-04,
mu0_g = NULL,
sig0_g = NULL
)A list containing the following arguments:
mu: The scale equivariant functional M-estimator .
mu0_g: mu0_g.
sig0_g: sig0_g.
Either an object of class fdata for monodimensional functional data or an object of class fdata2d for bi-dimensional functional data.
The family of loss function for the calculation of the equivariant functional M-estimator. The values allowed are "bisquare" for the bisquare or Tukey's biweight family of loss functions; "huber" for the the Huber's family of loss functions; "optimal" for the optimal family of loss functions; "hampel" for the the Hampel's family of loss functions; "median" for the median loss function. A non-robust functional estimator of the mean based on the standard least squares loss function is used with the value "mean". Default is "bisquare".
Asymptotic efficiency of the equivariant functional M-estimator. When family is either "mean" or "median", eff is ignored.
The maximum number of iterations allowed in the re-weighted least-squares algorithm to compute the equivariant functional M-estimator.
The tolerance for the stopping condition of the re-weighted least-squares algorithm to compute the equivariant functional M-estimator.
The algorithm stops when the relative variation of the weighted norm sum between two consecutive iterations is less than tol.
Initial estimate used in re-weighted least-squares algorithm to compute the equivariant functional M-estimator. If NULL the standard non-robust functional mean is used. Default is NULL.
Estimate of the standard error of X. If NULL, the functional mean is used. Default is NULL.
Centofanti, F., Colosimo, B. M., Grasso, M. L., Menafoglio, A., Palumbo, B., & Vantini, S. (2023). Robust functional ANOVA with application to additive manufacturing. Journal of the Royal Statistical Society Series C: Applied Statistics, 72(5), 1210-1234.
rofanova funmad
library(rofanova)
data_out<-simulate_data(scenario="one-way")
X_fdata<-data_out$X_fdata
per_list_median<-fusem(X_fdata)
Run the code above in your browser using DataLab